==> codegen-0.12.0.tgz: package/lib/generators/react-typescript/app/template/src/index.tsx <==
import "./core/i18n/i18n-init";
import React from "react";
import ReactDOM from "react-dom";
import "./index.css";
import "./core/screen-api/screen-registry";
import App from "./app/App";
import {
  ApolloClient,
  ApolloProvider,
  createHttpLink,
  InMemoryCache
} from "@apollo/client";
import "antd/dist/antd.min.css";
import axios from "axios";
import { HashRouter } from "react-router-dom";
import { onError } from "@apollo/client/link/error";
import { createIntl, IntlProvider } from "react-intl";
import { GRAPHQL_URI, REQUEST_SAME_ORIGIN } from "./config";
import {
  HotkeyContext,
  HotkeyStore,
  ScreenContext,
  Screens,
  localesStore
} from "@amplicode/react-core";
import { DevSupport } from "@react-buddy/ide-toolbox";
import { ComponentPreviews, useInitial } from "./dev";
import { defaultHotkeyConfigs } from "./core/hotkeys/hotkey-configs";
import { securityStore } from "./core/security/security-store";
import { notification } from "antd";
import "./core/addons/addons";

axios.interceptors.response.use(response => {
  if (response.status === 401) {
    securityStore.logout();
  }
  return response;
});
axios.defaults.withCredentials = !REQUEST_SAME_ORIGIN;

const httpLink = createHttpLink({
  uri: GRAPHQL_URI,
  credentials: REQUEST_SAME_ORIGIN ? "same-origin" : "include",
});

const errorLink = onError(({ networkError, graphQLErrors }) => {
  // TODO code below assumes that GraphQL server returns
  // {"errors":[{"extensions":{"classification":"UNAUTHORIZED"}}], ...}
  // for not authenticated user
  // and
  // {"errors":[{"extensions":{"classification":"FORBIDDEN"}}], ...}
  // if user has not enough permissions for query.
  // If the server handles errors differently, or has a different response structure, code below should be modified.

  if (graphQLErrors != null && graphQLErrors.length > 0) {
    if (
      graphQLErrors.some(
        err => err.extensions?.classification === "UNAUTHORIZED"
      )
    ) {
      securityStore.logout();
      return;
    }

    if (
      graphQLErrors.some(
        err => err.extensions?.classification === "FORBIDDEN"
      )
    ) {
      const intl = createIntl({locale: 'en', messages: localesStore.messagesMapping["en"]});
      notification.error({
        message: intl.formatMessage({ id: "common.notAllowed" })
      });
      return;
    }
  }

  if (networkError == null || !("statusCode" in networkError)) {
    return;
  }
  if (networkError.statusCode === 401) {
    securityStore.logout();
  }
});

const client = new ApolloClient({
  link: errorLink.concat(httpLink),
  cache: new InMemoryCache(),
  defaultOptions: {
    query: {
      fetchPolicy: "network-only"
    },
    watchQuery: {
      fetchPolicy: "network-only"
    }
  }
});

// To customize screens behavior, pass a config object to Screens constructor
const screens = new Screens();

const hotkeys = new HotkeyStore(defaultHotkeyConfigs);

ReactDOM.render(
  <React.StrictMode>
    <ApolloProvider client={client}>
      <IntlProvider locale="en" messages={localesStore.messagesMapping["en"]}>
        <ScreenContext.Provider value={screens}>
          <HashRouter>
            <HotkeyContext.Provider value={hotkeys}>
              <DevSupport
                ComponentPreviews={ComponentPreviews}
                useInitialHook={useInitial}
              >
                <App />
              </DevSupport>
            </HotkeyContext.Provider>
          </HashRouter>
        </ScreenContext.Provider>
      </IntlProvider>
    </ApolloProvider>
  </React.StrictMode>,
  document.getElementById("root")
);

==> codegen-0.15.0.tgz: package/lib/generators/react-typescript/app/template/src/index.tsx <==
import React from "react";
import ReactDOM from "react-dom";
import "./index.css";
import "./core/screen-api/screen-registry";
import App from "./app/App";
import {
  ApolloClient,
  ApolloProvider,
  createHttpLink,
  InMemoryCache
} from "@apollo/client";
import "antd/dist/antd.min.css";
import axios from "axios";
import { HashRouter } from "react-router-dom";
import { onError } from "@apollo/client/link/error";
import { GRAPHQL_URI, REQUEST_SAME_ORIGIN } from "./config";
import {
  HotkeyContext,
  HotkeyStore,
  ScreenContext,
  Screens,
  EventEmitter,
} from "@amplicode/react-core";
import { DevSupport } from "@react-buddy/ide-toolbox";
import { ComponentPreviews, useInitial } from "./dev";
import { defaultHotkeyConfigs } from "./core/hotkeys/hotkey-configs";
import "./core/addons/addons";
import { I18nProvider } from "./core/i18n/providers/I18nProvider";
import { ServerErrorInterceptor } from "./core/error/ServerErrorInterceptor";
import { ServerErrorEvents } from "./core/error/ServerErrorEvents";

export const serverErrorEmitter = new EventEmitter<ServerErrorEvents>();

axios.interceptors.response.use(response => {
  if (response.status === 401) {
    serverErrorEmitter.emit("unauthorized");
  }
  return response;
});
axios.defaults.withCredentials = !REQUEST_SAME_ORIGIN;

const httpLink = createHttpLink({
  uri: GRAPHQL_URI,
  credentials: REQUEST_SAME_ORIGIN ? "same-origin" : "include",
});

const errorLink = onError(errorResponse => serverErrorEmitter.emit('graphQLError', errorResponse));

const client = new ApolloClient({
  link: errorLink.concat(httpLink),
  cache: new InMemoryCache(),
  defaultOptions: {
    query: {
      fetchPolicy: "network-only"
    },
    watchQuery: {
      fetchPolicy: "network-only"
    }
  }
});

// To customize screens behavior, pass a config object to Screens constructor
const screens = new Screens();

const hotkeys = new HotkeyStore(defaultHotkeyConfigs);

ReactDOM.render(
  <React.StrictMode>
    <ApolloProvider client={client}>
      <I18nProvider>
        <ScreenContext.Provider value={screens}>
          <HashRouter>
            <HotkeyContext.Provider value={hotkeys}>
              <ServerErrorInterceptor serverErrorEmitter={serverErrorEmitter}>
                <DevSupport
                  ComponentPreviews={ComponentPreviews}
                  useInitialHook={useInitial}
                >
                  <App />
                </DevSupport>
              </ServerErrorInterceptor>
            </HotkeyContext.Provider>
          </HashRouter>
        </ScreenContext.Provider>
      </I18nProvider>
    </ApolloProvider>
  </React.StrictMode>,
  document.getElementById("root")
);
